"the jpe library"
from jpe.Jfloat import Jfloat as jfloat
del Jfloat
import jpe.random
import jpe.math
import jpe.crono
import jpe.utils

del jpe
